# ---------- preparation in advanca 事前準備--------------------------------------------------
# Install packages if not installed 必要なパッケージが無けれな自動でインストール-----
if(!require("ggpubr")) install.packages("ggpubr")
if(!require("dplyr")) install.packages("dplyr")
if(!require("ggplot2")) install.packages("ggplot2")
if(!require("ggfortify")) install.packages("ggfortify") #先に直接.tar.gzの圧縮fileをCRANからDLしてRstudioのPackgesウィンドウからインストール
if(!require("car")) install.packages("car") 
if(!require("NSM3")) install.packages("NSM3") #先に直接.tar.gzの圧縮fileをCRANからDLしてRstudioのPackgesウィンドウからインストール
if(!require("partitions")) install.packages("partitions")   #先に直接.tar.gzの圧縮fileをCRANからDLしてRstudioのPackgesウィンドウからインストール
if(!require("gmp")) install.packages("gmp")  #先に直接.tar.gzの圧縮fileをCRANからDLしてRstudioのPackgesウィンドウからインストール
if(!require("exactRankTests")) install.packages("exactRankTests")
if(!require("lawstat")) install.packages("lawstat") 
if(!require("effsize")) install.packages("effsize")
if(!require("effectsize")) install.packages("effectsize", repos = "https://easystats.r-universe.dev") 
if(!require("psych")) install.packages("psych")
if(!require("RColorBrewer")) install.packages("RColorBrewer") 
if(!require("gridExtra")) install.packages("gridExtra") 
if(!require("patchwork")) install.packages("patchwork") 
if(!require("ggExtra")) install.packages("ggExtra") 

# clear R's brain 一度参照したリストもしくは変数を次の作業で消す-----
rm(list = ls())

# Load libraries 必要なパッケージの読み込み-----
library(tidyverse)
library(ggpubr)
library(dplyr)        #データ整形に使う
library(ggplot2)
library(ggfortify) #needed for autoplot()
library(car)  #needed for Levene's test
library(NSM3)  #needed for Steel-Dwass test
library(partitions) 　#needed for NSM3, maybe
library(gmp) 　　　　 #needed for NSM3, maybe
library(exactRankTests) 
library(lawstat)  #needed for Brunner-Munzel test
library(effectsize)  
library(RColorBrewer) #カラーパレット、display.brewer.all() を実行すると一覧を表示
library(gridExtra) #複数のグラフを並べる
library(patchwork) #複数のグラフを並べる　いずれ選ぼう
library(ggExtra)  #plotの周辺にhistogramなどを表示

# Data input 今後以下のパスからデータを自動で読み込みする場合-----
library(readr)
d.cvfreq <- read.csv(file.choose())  #Run and choose cvfreqStatsSum.csv 
                                    #ここを実行（Run）するとfile選択画面になるので、どのfileを読み込んだか上に記録！


# # ----------prep done 準備だん------------------------------------------------------------

    
# 【0】基本的な統計と下準備 preparation for basic stats----------------------------

glimpse(d.cvfreq)

d.cvfreq %>% #上でオブジェクト化したデータテーブルを使って
  group_by(category.name) %>% 
    summarise( 
      mean_cvfreq = mean(cvfreq), 
      Var_cvfreq = var(cvfreq),
      SD_cvfreq = sd(cvfreq),
      SEM_cvfreq = sd(cvfreq)/sqrt(length(cvfreq)),
      Median_cvfreq = median(cvfreq)
      ) 

d.cvfreq %>% #上でオブジェクト化したデータテーブルを使って
  group_by(category.name) %>% 
  summarise( 
    mean_duration = mean(duration), 
    Var_duration = var(duration),
    SD_duration = sd(duration),
    SEM_duration = sd(duration)/sqrt(length(duration)),
    Median_duration = median(duration)
  ) 



# 【1】scatter plots for Duration & cvfreq　----------------------------

cor.test(x = d.cvfreq$duration, y = d.cvfreq$cvfreq, method="pearson")　#ピアソン（パラメトリック）
#cor.test(x = d.cvfreq$duration, y = d.cvfreq$cvfreq, method="spearman")　#スピアマン（ノンパラ）相関係数rじゃなくてρ（ロー）


sFig2a_scatt <-  #ここまで含めて実行するとオブジェクト化される（けどグラフは表示されないのでggplot以下だけ実行する）
ggplot(d.cvfreq, aes(x = duration, y = cvfreq, color = category.name)) +  
    #データセットと使用する変数の指定、color：群ごとにdotの色を変える、shape：群ごとにdotの形を変える
  scale_color_manual(values = c ("a. Upward" = "Salmon", "b. Downward" = "Orange", "c. Flat" = "goldenrod1", "d. Short" = "gold4", "e. Chevron" = "sandybrown", "f. Wave" = "brown1", "g. Complex" = "brown4", "h. One jump" = "royalblue", "i. More jump" = "Cyan3", "j. Harmonics" = "mediumvioletred", "k. OneJump+Ham" = "royalblue4", "l. MoreJump+Ham" = "darkcyan")) + 
    #色をRで自動指定したい場合上記関数を消す
  geom_point(size = 2, alpha = 0.5) +      #dotのサイズ指定
  geom_smooth(method = 'lm', colour = 'darkgrey') + #回帰直線とSEMのあてはめ（SEMを消したいときは se = FALSE を追加）
  xlab("duration (ms)") +      #X軸のラベル
  ylab("cvfreq") +  #Y軸のラベル
  ylim(0, 0.5) + xlim(0, 200) + 
  ggtitle("a") +
  theme_classic(base_size = 22, base_family = "Helvetica") +   # white backgrond グラフの背景を白に
  theme(legend.position = "none") #凡例を消したい時は#を消して有効にする



#comparison of means between----------------------------

#【cvfreq】------------
#データの分布など確認（診断プロット）
cvfreq.lm <-lm(cvfreq ~ category.name, data = d.cvfreq)
autoplot(cvfreq.lm, smooth.colour = NA) #ANOVAとか線形モデルを使う前提の診断プロット


#Welch's one-way ANOVA
oneway.test(d.cvfreq$cvfreq ~ d.cvfreq$category.name) #(データシート$従属変数 ~ データシート$独立変数)

#post-hoc multiple comparison （Welch用にプーリングしたSDを用いる pool.sd=T を指定）
pairwise.t.test(d.cvfreq$cvfreq, d.cvfreq$category.name, p.adj="holm", pool.sd=T)


sFig2b_cvfreqmean <- #グリッドして並べる際はこのコメントを消すことでオブジェクト化
ggplot(d.cvfreq, aes(x = category.name, y = cvfreq)) +  
  geom_jitter(shape = 21, size = 2, aes(fill = category.name), width = 0.2, alpha = 0.5) +  
    #ランダムなジッタープロット、position関数を使うとバグる、aesのfillにドットの色分け用グループ名を入れる
  scale_fill_manual(values = c ("a. Upward" = "Salmon", "b. Downward" = "Orange", "c. Flat" = "goldenrod1", "d. Short" = "gold4", "e. Chevron" = "sandybrown", "f. Wave" = "brown1", "g. Complex" = "brown4", "h. One jump" = "royalblue", "i. More jump" = "Cyan3", "j. Harmonics" = "mediumvioletred", "k. OneJump+Ham" = "royalblue4", "l. MoreJump+Ham" = "darkcyan")) + 
  #色をRで自動指定したい場合上記関数を消す
  stat_summary(fun.y = mean, geom = "crossbar", colour = "black", width = 0.4) +  #棒グラフにしたい場合はcrossbarをbarに変える
  stat_summary(fun.data = mean_se, geom = "errorbar", colour = "black", width = 0.2) +  #widthは横線の長さ
  ylim(0, 0.5) +     #Y軸の（最大値, 最小値）を指定する場合は記入して先頭の#を消す
  xlab("Call category") +      #X軸のラベル
  ggtitle("b") +
  coord_flip() +
  theme_classic(base_size = 20, base_family = "Helvetica") +
  theme(legend.position = "none")  #凡例を消したい時は#を消して上のcodeの最後に+を足して有効にする



#【Duration】------------
#データの分布など確認（診断プロット）
duration.lm <-lm(duration ~ category.name, data = d.cvfreq)
autoplot(duration.lm, smooth.colour = NA) #ANOVAとか線形モデルを使う前提の診断プロット


#Welch's one-way ANOVA
oneway.test(d.cvfreq$duration ~ d.cvfreq$category.name) #(データシート$従属変数 ~ データシート$独立変数)

#post-hoc multiple comparison （Welch用にプーリングしたSDを用いる pool.sd=T を指定）
pairwise.t.test(d.cvfreq$duration, d.cvfreq$category.name, p.adj="holm", pool.sd=T)


sFig2c_durmean <- #グリッドして並べる際はこのコメントを消すことでオブジェクト化
ggplot(d.cvfreq, aes(x = category.name, y = duration)) +  
  geom_jitter(shape = 21, size = 2, aes(fill = category.name), width = 0.2, alpha = 0.5) +  
  scale_fill_manual(values = c ("a. Upward" = "Salmon", "b. Downward" = "Orange", "c. Flat" = "goldenrod1", "d. Short" = "gold4", "e. Chevron" = "sandybrown", "f. Wave" = "brown1", "g. Complex" = "brown4", "h. One jump" = "royalblue", "i. More jump" = "Cyan3", "j. Harmonics" = "mediumvioletred", "k. OneJump+Ham" = "royalblue4", "l. MoreJump+Ham" = "darkcyan")) + 
  #色をRで自動指定したい場合上記関数を消す
  stat_summary(fun.y = mean, geom = "crossbar", colour = "black", width = 0.4) +  #棒グラフにしたい場合はcrossbarをbarに変える
  stat_summary(fun.data = mean_se, geom = "errorbar", colour = "black", width = 0.2) +  #widthは横線の長さ
  ylim(0, 200) +     #Y軸の（最大値, 最小値）を指定する場合は記入して先頭の#を消す
  ylab("duration (ms)") +      #X軸のラベル
  ggtitle("c") +
  coord_flip() +
  #facet_wrap(~場合わけ変数) +    #同じ操作を群ごとや個体ごとにする場合、場合わけ変数を~の後に指定
  theme_classic(base_size = 20, base_family = "Helvetica") +
  theme(axis.title.y=element_blank(),
        axis.text.y=element_blank(),
        axis.ticks.y=element_blank()) +
  theme(legend.position = "none")  #凡例を消したい時は#を消して上のcodeの最後に+を足して有効にする


#----comined sFig2----
sFig2a_scatt / (sFig2b_cvfreqmean | sFig2c_durmean)



#----【Jump or Non】---------------------------------------------------------------------

# 【1】scatter plots for Duration & cvfreq　----------------------------


#lm()で共分散分析もする場合
d.mod2 <-lm(cvfreq ~ duration*jump_non, data = d.cvfreq)
#「説明変数1*説明変数2」で指定
autoplot(d.mod2, smooth.colour = NA) #ANOVAとか線形モデルを使う前提の診断プロット
anova(d.mod2)   #交互作用などの結果を見るにはlm()の内容をanova()に渡す
summary(d.mod2) #詳しいデータも知りたいときはこれもやる

#群ごとに直線を当てはめたいときはこっちを使う
Fig_smootheach2pre <-　
ggplot(d.cvfreq, aes(x = duration, y = cvfreq, color = jump_non)) +  
  #データセットと使用する変数の指定、colour：群ごとにdotの色を変える、shape：群ごとにdotの形を変える
  scale_color_manual(values = c ("Jumps" = "Cyan3", "Non-jump" = "Salmon")) + 
  #色をRで自動指定したい場合上記関数を消す
  geom_point(size = 2, alpha = 0.5) +      #dotのサイズ指定
  #geom_smooth(method = 'lm', colour = 'darkgrey') + #回帰直線とSEMのあてはめ
  geom_smooth(method = 'lm', se = FALSE, mapping = aes(colour = jump_non)) +　#SEMを表示したいときは se = FALSE を消す
  xlim(0, 200) + ylim(0, 0.5) +
  xlab("duration (ms)") +      #X軸のラベル
  ylab("cvfreq") +  #Y軸のラベル
  ggtitle("a") +
  theme_classic(base_size = 18, base_family = "Helvetica") +   # white backgrond グラフの背景を白に
  theme(legend.position = "none")  #凡例を消したい時は#を消して有効にする


sFig3a_smootheach <-
ggMarginal(Fig_smootheach2pre, #先に作っておいたplotのオブジェクトを指定
  type = "histogram",
  margins = "both",
  position = 'identity', #この行でヒストグラムを「重ね合わせ」に指定（積み重ねではなく）
  size = 2, groupColour = TRUE, groupFill = TRUE,) 
#ggMarginalで作った図はなぜかpatchwarkでtilingしてくれないので注意 Note that diagrams created with ggMarginal will not be tiled by patchwark for some reason.


####----------sFig3aを自分で作るのに使った I used the scripts below to make sFig3a manually.---------
Fig_2histoFreq <-　
  ggplot(d.cvfreq, aes(x = cvfreq, fill = jump_non)) +  
  #データセットと使用する変数の指定、colour：群ごとにdotの色を変える、shape：群ごとにdotの形を変える
  scale_fill_manual(values = c ("Jumps" = "Cyan3", "Non-jump" = "Salmon")) + 
  #色をRで自動指定したい場合上記関数を消す
  geom_histogram(size = 0.5, alpha = 0.5, color = "Black", position = 'identity') + 
    #position = 'identity'で重ね合わせ、これが無ければ積み上げ
  #geom_smooth(method = 'lm', colour = 'darkgrey') + #回帰直線とSEMのあてはめ
  xlim(0, 0.5) + 
  xlab("cvfreq") +      #X軸のラベル
  ylab("count") +  #Y軸のラベル
  coord_flip() +
  theme_classic(base_size = 20, base_family = "Helvetica") +   # white backgrond グラフの背景を白に
  theme(legend.position = "none")  #凡例を消したい時は#を消して有効にする


Fig_2histoDur <-　
  ggplot(d.cvfreq, aes(x = duration, fill = jump_non)) +  
  #データセットと使用する変数の指定、colour：群ごとにdotの色を変える、shape：群ごとにdotの形を変える
  scale_fill_manual(values = c ("Jumps" = "Cyan3", "Non-jump" = "Salmon")) + 
  #色をRで自動指定したい場合上記関数を消す
  geom_histogram(size = 0.5, alpha = 0.5, color = "Black", position = 'identity') + 
    #position = 'identity'で重ね合わせ、これが無ければ積み上げ
  #geom_smooth(method = 'lm', colour = 'darkgrey') + #回帰直線とSEMのあてはめ
  xlim(0, 200) + 
  xlab("duration (ms)") +      #X軸のラベル
  ylab("count") +  #Y軸のラベル
  theme_classic(base_size = 20, base_family = "Helvetica") +   # white backgrond グラフの背景を白に
  theme(legend.position = "none")  #凡例を消したい時は#を消して有効にする
####----------------------------------------------------------------------------------


#-------comparison of means between----------------------------

#2群比較用の群を抽出
dJumps <-filter(d.cvfreq, jump_non == "Jumps")　#(元データ, 抽出したい群名がある列名 == "群名")
dNonjump <-filter(d.cvfreq, jump_non == "Non-jump") 



#【cvfreq】------------
#データの分布など確認（診断プロット）
cvfreq.lm2 <-lm(cvfreq ~ jump_non, data = d.cvfreq)
autoplot(cvfreq.lm2, smooth.colour = NA) #ANOVAとか線形モデルを使う前提の診断プロット


t.test(dJumps$cvfreq, dNonjump$cvfreq) #Welch's t-test 


sFig3b_cvfreqmean <- #グリッドして並べる際はこのコメントを消すことでオブジェクト化
  ggplot(d.cvfreq, aes(x = jump_non, y = cvfreq, fill = jump_non)) +  
  geom_jitter(shape = 21, size = 2, aes(fill = jump_non), width = 0.2, alpha = 0.5) +  
  geom_violin(alpha = 0.2) +
  #ランダムなジッタープロット、position関数を使うとバグる、aesのfillにドットの色分け用グループ名を入れる
  scale_fill_manual(values = c ("Jumps" = "Cyan3", "Non-jump" = "Salmon")) + 
  #色をRで自動指定したい場合上記関数を消す
  stat_summary(fun.y = mean, geom = "crossbar", colour = "black", width = 0.4) +  #棒グラフにしたい場合はcrossbarをbarに変える
  stat_summary(fun.data = mean_se, geom = "errorbar", colour = "black", width = 0.2) +  #widthは横線の長さ
  ylim(0, 0.5) +     #Y軸の（最大値, 最小値）を指定する場合は記入して先頭の#を消す
  #xlab("Call category") +      #X軸のラベル
  ggtitle("b") +
  #coord_flip() +
  theme_classic(base_size = 20, base_family = "Helvetica") +
  theme(axis.title.x=element_blank()) +
  #axis.text.y=element_blank(), axis.ticks.y=element_blank()) +
  theme(legend.position = "none")  #凡例を消したい時は#を消して上のcodeの最後に+を足して有効にする



#【Duration】------------
#データの分布など確認（診断プロット）
duration.lm <-lm(duration ~ jump_non, data = d.cvfreq)
autoplot(duration.lm, smooth.colour = NA) #ANOVAとか線形モデルを使う前提の診断プロット


t.test(dJumps$duration, dNonjump$duration) #Welch's t-test 


sFig3c_durmean <- #グリッドして並べる際はこのコメントを消すことでオブジェクト化
  ggplot(d.cvfreq, aes(x = jump_non, y = duration, fill = jump_non)) +  
  geom_jitter(shape = 21, size = 2, aes(fill = jump_non), width = 0.2, alpha = 0.5) +  
  geom_violin(alpha = 0.2) +
  scale_fill_manual(values = c ("Jumps" = "Cyan3", "Non-jump" = "Salmon")) + 
  #色をRで自動指定したい場合上記関数を消す
  stat_summary(fun.y = mean, geom = "crossbar", colour = "black", width = 0.4) +  #棒グラフにしたい場合はcrossbarをbarに変える
  stat_summary(fun.data = mean_se, geom = "errorbar", colour = "black", width = 0.2) +  #widthは横線の長さ
  ylim(0, 200) +     #Y軸の（最大値, 最小値）を指定する場合は記入して先頭の#を消す
  #xlab("") +      #X軸のラベル
  ylab("duration (ms)") + 
  ggtitle("c") +
  #coord_flip() +
  #facet_wrap(~場合わけ変数) +    #同じ操作を群ごとや個体ごとにする場合、場合わけ変数を~の後に指定
  theme_classic(base_size = 20, base_family = "Helvetica") +
  theme(axis.title.x=element_blank()) +
        #axis.text.y=element_blank(), axis.ticks.y=element_blank()) +
  theme(legend.position = "none")  #凡例を消したい時は#を消して上のcodeの最後に+を足して有効にする



rmarkdown::render("sFigs2-3StatSum.Rmd", "word_document") #word output
rmarkdown::render("sFigs2-3StatSum.Rmd", "html_document") #HTML output

